% alibi-detect documentation master file, created by
% sphinx-quickstart on Thu Feb 28 11:04:41 2019.
% You can adapt this file completely to your liking, but it should at least
% contain the root `toctree` directive.

```{include} landing.md
```

```{toctree}
:caption: Overview
:maxdepth: 1

overview/getting_started
overview/algorithms
overview/saving
overview/roadmap
```

```{toctree}
:caption: Outlier Detection
:maxdepth: 2

od/methods
od/examples
```

```{toctree}
:caption: Drift Detection
:maxdepth: 2

cd/background
cd/methods
cd/examples
```

```{toctree}
:caption: Adversarial Detection
:maxdepth: 2

ad/methods
ad/examples
```

```{toctree}
:caption: Deployment
:glob: true
:maxdepth: 1

examples/alibi_detect_deploy
```

```{toctree}
:caption: Datasets
:maxdepth: 1

datasets/overview
```

```{toctree}
:caption: Models
:maxdepth: 1

models/overview
```

```{toctree}
:caption: API reference
:maxdepth: 1

API reference <api/modules>
```

```{toctree}
:caption: Bibliography
:glob: true
:maxdepth: 1

bib
```

